Coverage for airflow/contrib/operators.py: 100%

# Coverage for airflow/contrib/operators.py : 100%

## 3 statements 3 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 | # Imports the operators dynamically while keeping the package API clean, # abstracting the underlying modules from airflow.utils import import_module_attrs as _import_module_attrs _operators = { 'vertica_operator': ['VerticaOperator'], 'vertica_to_hive': ['VerticaToHiveTransfer'], } _import_module_attrs(globals(), _operators)